@@ -1,7 +1,7 @@
 /***************************************************************
 LanceMan's quickplot --- a fast interactive 2D plotter
 
-Copyright (C) 1998  Lance Arsenault
+Copyright (C) 1998, 1999  Lance Arsenault
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,8 +17,10 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-***********************************************************************/
-/* $Id: xwin.h,v 1.3 1998/04/08 02:19:53 lance Exp $ */
+Or look at http://www.gnu.org/copyleft/gpl.html .
+
+**********************************************************************/
+/* $Id: xwin.h,v 1.5 1999/02/27 04:21:59 lance Exp $ */
 #include <X11/Intrinsic.h>
 
 /* mouse mode flags available */
@@ -29,12 +31,16 @@ typedef struct
 {
   XtAppContext context;
   Widget toplevelWig, managerWig, plotWig, 
-    quitWig, popWig, *valueWig, menuWig ,modeWig, redrawWig;
+    quitWig, popWig, *valueWig, menuWig ,modeWig, redrawWig, saveButtonWig,
+    saveInputWig;
+  unsigned long grey_pix;
+  XFontStruct *font_struct;
+  int savefile_count;
   int  screen_number;
   Display *display;
   Window plotwin, quitwin;
   Pixmap plot0pix;
-  unsigned long backgroundColor;
+  unsigned long BWbackground_pix, BWforeground_pix;
   Window valuewin;
   int popflag;
   GC gc;
